import typing
import collections.abc
import typing_extensions

class RawBlendFileReader:
    """Return a file handle to the raw blend file data (abstracting compressed formats)."""

def main(): ...
def read_blend_rend_chunk(filepath): ...
